@@ -10,7 +10,7 @@
 
 #include <QCoreApplication>
 
-#include <KCoreAddons/KAboutData>
+#include <KAboutData>
 
 MediaPlayer2::MediaPlayer2(QObject *parent)
     : QDBusAbstractAdaptor(parent)
